<!-- 位置报表 -->
<template>
  <div class="rightContent">
    <div class="top">
      <SearchCommonView
        :add-title="'新建'"
        :showAdd="false"
        :placeholder="'请输入位置名称、产品名称或产品类别'"
        :amount-view="false"
        @addCommonClick="addBtnClick"
        @searchClick="getList"
        :isDisabled="true"
      />
    </div>
    <div class="list-view">
      <div class="table">
        <TableCommonView
          ref="tableListRef"
          :table-list="tableList"
          @selTableCol="selTableCol"
          @tableRowClick="tableRowClick"
          :showSummary="true"
        >
          <template slot="tableButton">
            <el-table-column label="操作" width="210" align="center">
              <template slot-scope="scope">
                <span @click="handleHistoryClick(scope.row)" class="yes-cursor">
                  <i class="el-icon-refresh-left"></i>
                  <span>历史</span>
                </span>
                <span @click="handleAddGoods(scope)" class="margin_left_5px no-cursor">
                  <i class="el-icon-refresh"></i>
                  <span>补货</span>
                </span>
              </template>
            </el-table-column>
          </template>
        </TableCommonView>
      </div>
      <div class="btn-pager">
        <PagerView class="page" :pager-options="pagerOptions" v-on="pagerEvents" />
      </div>
    </div>
    <!-- 编辑 -->
    <AddOverviewDialog v-if="editConfig.visible" :edit-common-config="editConfig" :add-name="this.$route.params.name" />
  </div>
</template>

<script>
import pageMixin from "@/components/makepager/pager/mixin/pageMixin"
import { getLocationData } from "@/api/locationApi/locationApi"
import AddOverviewDialog from "@/views/overview/AddOverviewDialog"

export default {
  name: "InventoryReport",
  props: {},
  components: { AddOverviewDialog },
  mixins: [pageMixin],
  computed: {},
  data() {
    return {
      tableList: {},
      showcol: [ "产品类别",  "价值"],
      // countcol: [
      //   { label: "在库数量", unit: "" },
      //   { label: "预留数量", unit: "" },
      //   { label: "价值", unit: "￥" },
      // ],
      countcol: ["在库数量", "预留数量", "价值"],
      testArr: [
        {
          product: "HC/销售区/b区",
          category: "丝绸制品/真丝睡袍",
          cost: "800.00",
          totalPrices: "2000.00",
          inStore: "00.00",
          availableStore: "200.00",
          inStorage: "00.00",
          toStore: 65432.0,
          forecast: "0.00",
          unit: "件"
        },
        {
          product: "HC销售区/A区",
          category: "丝绸制品/金丝睡袍",
          cost: "9980.00",
          totalPrices: "00.00",
          inStore: "00.00",
          availableStore: "20.00",
          inStorage: "0.00",
          toStore: 32618.0,
          forecast: "0.00",
          unit: "件"
        }
      ],
      searchOptions: [],
      commonDetail: {
        visible: false,
        title: "新建",
        infomation: {}
      },
      editConfig: {
        visible: false,
        title: "新建",
        infomation: {}
      },
      productId: this.$route.params.id,
      productName: this.$route.params.name,
      metaTitle: this.$route.meta.title,
      keyWord:''
    }
  },
  created() {
    this.setTable()
    this.getData()
  },
  methods: {
    setTable() {
      this.tableList = {
        tableInfomation: [],
        selectBox: false,
        selectIndex: true,
        showcol: this.showcol,
        countcol: this.countcol,
        allcol: [],
        tableColumn: this.setTableColumn(this.showcol)
      }
      let allcol = []
      for (let i = 0; i < this.tableList.tableColumn.length; i++) {
        if (!this.tableList.tableColumn[i].default) {
          const label = this.tableList.tableColumn[i].label
          allcol.push(label)
        }
      }
      this.tableList.allcol = allcol
    },
    setTableColumn(showcol) {
      let tableColumn = [
        {
          label: "位置",
          prop: "locationName",
          default: true,
          isShowColumn: true
        },

        {
          label: "存储类别",
          prop: "category",
          default: false,
          isShowColumn: showcol.includes("存储类别")
        },
        {
          label: "产品",
          prop: "productName",
          default: true,
          isShowColumn: true
        },
        {
          label: "产品类别",
          prop: "productTypeName",
          default: false,
          isShowColumn: showcol.includes("产品类别")
        },
        {
          label: "在库数量",
          prop: "amount",
          isShowColumn: true,
          default: true,
          unit: "",
          textAlign:"right"
        },
        {
          label: "预留数量",
          prop: "availableStore",
          default: false,
          isShowColumn: showcol.includes("预留数量"),
          unit: "",
          textAlign:"right"
        },
        {
          label: "单位",
          prop: "unit",
          width: 120,
          default: false,
          isShowColumn: showcol.includes("单位")
        },
        {
          label: "价值",
          prop: "value",
          width: 120,
          default: false,
          isShowColumn: showcol.includes("价值"),
          textAlign:"right",
          unit: "￥"
        }
      ]
      return tableColumn
    },
    selTableCol(val) {
      this.showcol = val
      this.tableList.tableColumn = this.setTableColumn(val)
    },
    // 请求数据
    async getLocationData(params) {
      await getLocationData(params).then((res) => {
        if (res.code === 200) {
          const list = res.data
          this.tableList.tableInfomation = list || []
          this.pagerOptions.totalCount = res.total
        }
      })
    },
    getData() {
      if(this.$route.params.name==="库存报表"){
        this.getLocationData({
        wareHouseCode:this.$route.params.wareHouseCode,
        productId:this.$route.params.productId,
        page: this.pagerOptions.currPage,
        pageSize: this.pagerOptions.pageSize
      })
      }else{
        let params={
          page: this.pagerOptions.currPage,
          pageSize: this.pagerOptions.pageSize,
          keyWord:this.keyWord,
        }
        if(this.$route.params.locationId){
          params.locationId=this.$route.params.locationId
        }
        this.getLocationData(params)
      }
    },

    // 搜索
    getList(val) {
      this.keyWord=val
      this.getData()
    },
    // 行点击
    tableRowClick(row) {
      console.log(row)
      // this.editConfig.visible = true;
      this.editConfig.title = "查看"
      this.editConfig.infomation = { ...row }
    },
    // 新建
    addBtnClick() {
      this.editConfig.visible = true
      this.editConfig.title = "新建"
      this.getData()
    },
    // 状态
    getStatus(val) {
      return val === 1 ? "草稿" : val === 3 ? "就绪" : "完成"
    },
    // 历史
    handleHistoryClick(row) {
      console.log(row)
      this.$router.push({
        name: "inboundOutboundDetail",
        params: {
          keyWord:row.productTypeName,
          produceId:row.produceId,
          productName:row.productName,
          unit:row.unit,
          name: "报表"
        }
      })
    },
    // 补货
    handleAddGoods() {}
  }
}
</script>

<!-- Add "scoped" attribute to limit CSS to this component only -->
<style lang="scss" scoped>
</style>
